package com.fastbee.deviceData.api.renke.service;

import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import java.util.concurrent.TimeUnit;

@Service
public class RenkeDeviceDataService {
    @Autowired
    private StringRedisTemplate stringRedisTemplate;


    /**
     * 获取设备实时数据
     * @param deviceAddrs 设备地址，支持多个用英文逗号分隔
     */
    public void getDeviceRealtimeData(String deviceAddrs) {
        //处理鉴权
        String token = getAuth();
        //获取设备实时数据
        HttpResponse response = HttpRequest.get("http://api.farm.0531yun.cn/api/v2.0/entrance/device/getRealTimeData")
                .header("token", token)
                .form("deviceAddrs", deviceAddrs)
                .execute();
        String respBodyStr = response.body();
        if(StringUtils.isBlank(respBodyStr)) {
            throw new RuntimeException("获取设备实时数据失败!");
        }
        JSONObject respBody = JSONUtil.parseObj(respBodyStr);
        JSONArray realtimeDataList = JSONUtil.parseArray(respBody.get("data"));
        System.err.println("设备实时数据："+realtimeDataList);
    }


























    //获取token
    private String getAuth(){
        //判断token是否过期
        String cacheToken = stringRedisTemplate.opsForValue().get("rkckth:user:token");
        if (!Objects.isNull(cacheToken)){
            System.err.println("缓存中获取token:"+cacheToken);
            return cacheToken;
        }
        //获取token
        //构建请求体
        Map<String,Object> reqBody =new HashMap<>();
        reqBody.put("loginName","heilongjiang");
        reqBody.put("loginPwd","123456");

        HttpResponse response = HttpRequest.post("http://api.farm.0531yun.cn/api/v2.0/entrance/user/userLogin")
                .body(JSONUtil.toJsonStr(reqBody)).execute();
        System.err.println("响应："+response.body());
        String resultObjectStr = response.body();
        if(StringUtils.isBlank(response.toString())){
            throw new RuntimeException("获取token失败!");
        }
        JSONObject resultObject = JSONUtil.parseObj(resultObjectStr);
        JSONObject tokenObject = JSONUtil.parseObj(resultObject.get("data"));
        int currDate = Integer.parseInt(tokenObject.get("currDate").toString());
        int expDate = Integer.parseInt(tokenObject.get("expDate").toString());
        Integer periodValidity= expDate - currDate;
        //将token存入redis
        stringRedisTemplate.opsForValue().set("rkckth:user:token", tokenObject.get("token").toString(),2, TimeUnit.HOURS);
        System.err.println("请求获取到token:"+tokenObject.get("token").toString());
        return stringRedisTemplate.opsForValue().get("rkckth:user:token").toString();
    }
}
