package com.fastbee.deviceData.service.impl;

import java.util.List;
import com.fastbee.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fastbee.deviceData.mapper.DeviceRealtimedataMeteorologyMapper;
import com.fastbee.deviceData.domain.DeviceRealtimedataMeteorology;
import com.fastbee.deviceData.service.IDeviceRealtimedataMeteorologyService;

/**
 * 气象设备实时数据Service业务层处理
 * 
 * @author kerwincui
 * @date 2024-11-08
 */
@Service
public class DeviceRealtimedataMeteorologyServiceImpl implements IDeviceRealtimedataMeteorologyService 
{
    @Autowired
    private DeviceRealtimedataMeteorologyMapper deviceRealtimedataMeteorologyMapper;

    /**
     * 查询气象设备实时数据
     * 
     * @param nodeId 气象设备实时数据主键
     * @return 气象设备实时数据
     */
    @Override
    public DeviceRealtimedataMeteorology selectDeviceRealtimedataMeteorologyByNodeId(Long nodeId)
    {
        return deviceRealtimedataMeteorologyMapper.selectDeviceRealtimedataMeteorologyByNodeId(nodeId);
    }

    /**
     * 查询气象设备实时数据列表
     * 
     * @param deviceRealtimedataMeteorology 气象设备实时数据
     * @return 气象设备实时数据
     */
    @Override
    public List<DeviceRealtimedataMeteorology> selectDeviceRealtimedataMeteorologyList(DeviceRealtimedataMeteorology deviceRealtimedataMeteorology)
    {
        return deviceRealtimedataMeteorologyMapper.selectDeviceRealtimedataMeteorologyList(deviceRealtimedataMeteorology);
    }

    /**
     * 新增气象设备实时数据
     * 
     * @param deviceRealtimedataMeteorology 气象设备实时数据
     * @return 结果
     */
    @Override
    public int insertDeviceRealtimedataMeteorology(DeviceRealtimedataMeteorology deviceRealtimedataMeteorology)
    {
        deviceRealtimedataMeteorology.setCreateTime(DateUtils.getNowDate());
        return deviceRealtimedataMeteorologyMapper.insert(deviceRealtimedataMeteorology);
    }

    /**
     * 修改气象设备实时数据
     * 
     * @param deviceRealtimedataMeteorology 气象设备实时数据
     * @return 结果
     */
    @Override
    public int updateDeviceRealtimedataMeteorology(DeviceRealtimedataMeteorology deviceRealtimedataMeteorology)
    {
        return deviceRealtimedataMeteorologyMapper.updateDeviceRealtimedataMeteorology(deviceRealtimedataMeteorology);
    }

    /**
     * 批量删除气象设备实时数据
     * 
     * @param nodeIds 需要删除的气象设备实时数据主键
     * @return 结果
     */
    @Override
    public int deleteDeviceRealtimedataMeteorologyByNodeIds(Long[] nodeIds)
    {
        return deviceRealtimedataMeteorologyMapper.deleteDeviceRealtimedataMeteorologyByNodeIds(nodeIds);
    }

    /**
     * 删除气象设备实时数据信息
     * 
     * @param nodeId 气象设备实时数据主键
     * @return 结果
     */
    @Override
    public int deleteDeviceRealtimedataMeteorologyByNodeId(Long nodeId)
    {
        return deviceRealtimedataMeteorologyMapper.deleteDeviceRealtimedataMeteorologyByNodeId(nodeId);
    }
}
